@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,14 +33,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.redis_v1.services.cloud_redis import pagers
-from google.cloud.redis_v1.types import cloud_redis
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import CloudRedisTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import CloudRedisGrpcAsyncIOTransport
+
+from google.cloud.redis_v1.services.cloud_redis import pagers
+from google.cloud.redis_v1.types import cloud_redis
+
 from .client import CloudRedisClient
+from .transports.base import DEFAULT_CLIENT_INFO, CloudRedisTransport
+from .transports.grpc_asyncio import CloudRedisGrpcAsyncIOTransport
 
 
 class CloudRedisAsyncClient:
@@ -242,14 +244,13 @@ class CloudRedisAsyncClient:
         regions available to the project are queried, and the results
         are aggregated.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
 
-            def sample_list_instances():
+            async def sample_list_instances():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1.ListInstancesRequest(
@@ -260,7 +261,7 @@ class CloudRedisAsyncClient:
                 page_result = client.list_instances(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -323,12 +324,20 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListInstancesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -349,9 +358,9 @@ class CloudRedisAsyncClient:
 
             from google.cloud import redis_v1
 
-            def sample_get_instance():
+            async def sample_get_instance():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1.GetInstanceRequest(
@@ -359,7 +368,7 @@ class CloudRedisAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_instance(request=request)
+                response = await client.get_instance(request=request)
 
                 # Handle the response
                 print(response)
@@ -418,7 +427,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -437,14 +451,13 @@ class CloudRedisAsyncClient:
         This information is not included in the details returned
         to GetInstance.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
 
-            def sample_get_instance_auth_string():
+            async def sample_get_instance_auth_string():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1.GetInstanceAuthStringRequest(
@@ -452,7 +465,7 @@ class CloudRedisAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_instance_auth_string(request=request)
+                response = await client.get_instance_auth_string(request=request)
 
                 # Handle the response
                 print(response)
@@ -511,7 +524,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -542,14 +560,13 @@ class CloudRedisAsyncClient:
         The returned operation is automatically deleted after a few
         hours, so there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
 
-            def sample_create_instance():
+            async def sample_create_instance():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 instance = redis_v1.Instance()
@@ -568,7 +585,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -656,7 +673,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -686,14 +708,13 @@ class CloudRedisAsyncClient:
         operation is automatically deleted after a few hours, so
         there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
 
-            def sample_update_instance():
+            async def sample_update_instance():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 instance = redis_v1.Instance()
@@ -710,7 +731,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -792,7 +813,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -818,14 +844,13 @@ class CloudRedisAsyncClient:
         r"""Upgrades Redis instance to the newer Redis version
         specified in the request.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
 
-            def sample_upgrade_instance():
+            async def sample_upgrade_instance():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1.UpgradeInstanceRequest(
@@ -838,7 +863,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -911,7 +936,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -944,14 +974,13 @@ class CloudRedisAsyncClient:
         The returned operation is automatically deleted after a
         few hours, so there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
 
-            def sample_import_instance():
+            async def sample_import_instance():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 input_config = redis_v1.InputConfig()
@@ -967,7 +996,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1040,7 +1069,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1069,14 +1103,13 @@ class CloudRedisAsyncClient:
         The returned operation is automatically deleted after a
         few hours, so there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
 
-            def sample_export_instance():
+            async def sample_export_instance():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 output_config = redis_v1.OutputConfig()
@@ -1092,7 +1125,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1165,7 +1198,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1192,14 +1230,13 @@ class CloudRedisAsyncClient:
         replica node for a specific STANDARD tier Cloud
         Memorystore for Redis instance.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
 
-            def sample_failover_instance():
+            async def sample_failover_instance():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1.FailoverInstanceRequest(
@@ -1211,7 +1248,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1285,7 +1322,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1310,14 +1352,13 @@ class CloudRedisAsyncClient:
         r"""Deletes a specific Redis instance.  Instance stops
         serving and data is deleted.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
 
-            def sample_delete_instance():
+            async def sample_delete_instance():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1.DeleteInstanceRequest(
@@ -1329,7 +1370,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1403,7 +1444,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1430,14 +1476,13 @@ class CloudRedisAsyncClient:
         r"""Reschedule maintenance for a given instance in a
         given project and location.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
 
-            def sample_reschedule_maintenance():
+            async def sample_reschedule_maintenance():
                 # Create a client
-                client = redis_v1.CloudRedisClient()
+                client = redis_v1.CloudRedisAsyncClient()
 
                 # Initialize request argument(s)
                 request = redis_v1.RescheduleMaintenanceRequest(
@@ -1450,7 +1495,7 @@ class CloudRedisAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1533,7 +1578,12 @@ class CloudRedisAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1555,7 +1605,9 @@ class CloudRedisAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-redis",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-redis",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
