@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,12 +36,14 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.redis_v1.services.cloud_redis import pagers
-from google.cloud.redis_v1.types import cloud_redis
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import CloudRedisTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.redis_v1.services.cloud_redis import pagers
+from google.cloud.redis_v1.types import cloud_redis
+
+from .transports.base import DEFAULT_CLIENT_INFO, CloudRedisTransport
 from .transports.grpc import CloudRedisGrpcTransport
 from .transports.grpc_asyncio import CloudRedisGrpcAsyncIOTransport
 
@@ -58,7 +60,10 @@ class CloudRedisClientMeta(type):
     _transport_registry["grpc"] = CloudRedisGrpcTransport
     _transport_registry["grpc_asyncio"] = CloudRedisGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[CloudRedisTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[CloudRedisTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -184,10 +189,16 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         return self._transport
 
     @staticmethod
-    def instance_path(project: str, location: str, instance: str,) -> str:
+    def instance_path(
+        project: str,
+        location: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified instance string."""
         return "projects/{project}/locations/{location}/instances/{instance}".format(
-            project=project, location=location, instance=instance,
+            project=project,
+            location=location,
+            instance=instance,
         )
 
     @staticmethod
@@ -200,7 +211,9 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -213,9 +226,13 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -224,9 +241,13 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -235,9 +256,13 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -246,10 +271,14 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -443,7 +472,6 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         regions available to the project are queried, and the results
         are aggregated.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
@@ -524,12 +552,20 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListInstancesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -619,7 +655,12 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -638,7 +679,6 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         This information is not included in the details returned
         to GetInstance.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
@@ -712,7 +752,12 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -743,7 +788,6 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         The returned operation is automatically deleted after a few
         hours, so there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
@@ -857,7 +901,12 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -887,7 +936,6 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         operation is automatically deleted after a few hours, so
         there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
@@ -993,7 +1041,12 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1019,7 +1072,6 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         r"""Upgrades Redis instance to the newer Redis version
         specified in the request.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
@@ -1112,7 +1164,12 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1145,7 +1202,6 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         The returned operation is automatically deleted after a
         few hours, so there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
@@ -1241,7 +1297,12 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1270,7 +1331,6 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         The returned operation is automatically deleted after a
         few hours, so there is no need to call DeleteOperation.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
@@ -1366,7 +1426,12 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1393,7 +1458,6 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         replica node for a specific STANDARD tier Cloud
         Memorystore for Redis instance.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
@@ -1486,7 +1550,12 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1511,7 +1580,6 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         r"""Deletes a specific Redis instance.  Instance stops
         serving and data is deleted.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
@@ -1604,7 +1672,12 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1631,7 +1704,6 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         r"""Reschedule maintenance for a given instance in a
         given project and location.
 
-
         .. code-block:: python
 
             from google.cloud import redis_v1
@@ -1734,7 +1806,12 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1763,7 +1840,9 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-redis",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-redis",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
