@@ -15,23 +15,24 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.longrunning import operations_pb2  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 from google.cloud.redis_v1beta1.types import cloud_redis
-from google.longrunning import operations_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-redis",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-redis",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -80,6 +81,7 @@ class CloudRedisTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -121,10 +123,14 @@ class CloudRedisTransport(abc.ABC):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_instances: gapic_v1.method.wrap_method(
-                self.list_instances, default_timeout=600.0, client_info=client_info,
+                self.list_instances,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.get_instance: gapic_v1.method.wrap_method(
-                self.get_instance, default_timeout=600.0, client_info=client_info,
+                self.get_instance,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.get_instance_auth_string: gapic_v1.method.wrap_method(
                 self.get_instance_auth_string,
@@ -132,25 +138,39 @@ class CloudRedisTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_instance: gapic_v1.method.wrap_method(
-                self.create_instance, default_timeout=600.0, client_info=client_info,
+                self.create_instance,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.update_instance: gapic_v1.method.wrap_method(
-                self.update_instance, default_timeout=600.0, client_info=client_info,
+                self.update_instance,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.upgrade_instance: gapic_v1.method.wrap_method(
-                self.upgrade_instance, default_timeout=600.0, client_info=client_info,
+                self.upgrade_instance,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.import_instance: gapic_v1.method.wrap_method(
-                self.import_instance, default_timeout=600.0, client_info=client_info,
+                self.import_instance,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.export_instance: gapic_v1.method.wrap_method(
-                self.export_instance, default_timeout=600.0, client_info=client_info,
+                self.export_instance,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.failover_instance: gapic_v1.method.wrap_method(
-                self.failover_instance, default_timeout=600.0, client_info=client_info,
+                self.failover_instance,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.delete_instance: gapic_v1.method.wrap_method(
-                self.delete_instance, default_timeout=600.0, client_info=client_info,
+                self.delete_instance,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.reschedule_maintenance: gapic_v1.method.wrap_method(
                 self.reschedule_maintenance,
@@ -162,9 +182,9 @@ class CloudRedisTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -277,5 +297,9 @@ class CloudRedisTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("CloudRedisTransport",)
