@@ -13,14 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.type import dayofweek_pb2  # type: ignore
 from google.type import timeofday_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.redis.v1beta1",
@@ -66,8 +64,14 @@ class NodeInfo(proto.Message):
             Output only. Location of the node.
     """
 
-    id = proto.Field(proto.STRING, number=1,)
-    zone = proto.Field(proto.STRING, number=2,)
+    id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    zone = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class Instance(proto.Message):
@@ -91,7 +95,7 @@ class Instance(proto.Message):
         display_name (str):
             An arbitrary and optional user-provided name
             for the instance.
-        labels (Sequence[google.cloud.redis_v1beta1.types.Instance.LabelsEntry]):
+        labels (Mapping[str, str]):
             Resource labels to represent user provided
             metadata
         location_id (str):
@@ -157,7 +161,7 @@ class Instance(proto.Message):
         status_message (str):
             Output only. Additional information about the
             current status of this instance, if available.
-        redis_configs (Sequence[google.cloud.redis_v1beta1.types.Instance.RedisConfigsEntry]):
+        redis_configs (Mapping[str, str]):
             Optional. Redis configuration parameters, according to
             http://redis.io/topics/config. Currently, the only supported
             parameters are:
@@ -279,48 +283,142 @@ class Instance(proto.Message):
         READ_REPLICAS_DISABLED = 1
         READ_REPLICAS_ENABLED = 2
 
-    name = proto.Field(proto.STRING, number=1,)
-    display_name = proto.Field(proto.STRING, number=2,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=3,)
-    location_id = proto.Field(proto.STRING, number=4,)
-    alternative_location_id = proto.Field(proto.STRING, number=5,)
-    redis_version = proto.Field(proto.STRING, number=7,)
-    reserved_ip_range = proto.Field(proto.STRING, number=9,)
-    secondary_ip_range = proto.Field(proto.STRING, number=30,)
-    host = proto.Field(proto.STRING, number=10,)
-    port = proto.Field(proto.INT32, number=11,)
-    current_location_id = proto.Field(proto.STRING, number=12,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
+    location_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    alternative_location_id = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    redis_version = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    reserved_ip_range = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    secondary_ip_range = proto.Field(
+        proto.STRING,
+        number=30,
+    )
+    host = proto.Field(
+        proto.STRING,
+        number=10,
+    )
+    port = proto.Field(
+        proto.INT32,
+        number=11,
+    )
+    current_location_id = proto.Field(
+        proto.STRING,
+        number=12,
+    )
     create_time = proto.Field(
-        proto.MESSAGE, number=13, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=13,
+        message=timestamp_pb2.Timestamp,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=14,
+        enum=State,
+    )
+    status_message = proto.Field(
+        proto.STRING,
+        number=15,
+    )
+    redis_configs = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=16,
+    )
+    tier = proto.Field(
+        proto.ENUM,
+        number=17,
+        enum=Tier,
+    )
+    memory_size_gb = proto.Field(
+        proto.INT32,
+        number=18,
+    )
+    authorized_network = proto.Field(
+        proto.STRING,
+        number=20,
+    )
+    persistence_iam_identity = proto.Field(
+        proto.STRING,
+        number=21,
+    )
+    connect_mode = proto.Field(
+        proto.ENUM,
+        number=22,
+        enum=ConnectMode,
+    )
+    auth_enabled = proto.Field(
+        proto.BOOL,
+        number=23,
     )
-    state = proto.Field(proto.ENUM, number=14, enum=State,)
-    status_message = proto.Field(proto.STRING, number=15,)
-    redis_configs = proto.MapField(proto.STRING, proto.STRING, number=16,)
-    tier = proto.Field(proto.ENUM, number=17, enum=Tier,)
-    memory_size_gb = proto.Field(proto.INT32, number=18,)
-    authorized_network = proto.Field(proto.STRING, number=20,)
-    persistence_iam_identity = proto.Field(proto.STRING, number=21,)
-    connect_mode = proto.Field(proto.ENUM, number=22, enum=ConnectMode,)
-    auth_enabled = proto.Field(proto.BOOL, number=23,)
     server_ca_certs = proto.RepeatedField(
-        proto.MESSAGE, number=25, message="TlsCertificate",
+        proto.MESSAGE,
+        number=25,
+        message="TlsCertificate",
     )
     transit_encryption_mode = proto.Field(
-        proto.ENUM, number=26, enum=TransitEncryptionMode,
+        proto.ENUM,
+        number=26,
+        enum=TransitEncryptionMode,
     )
     maintenance_policy = proto.Field(
-        proto.MESSAGE, number=27, message="MaintenancePolicy",
+        proto.MESSAGE,
+        number=27,
+        message="MaintenancePolicy",
     )
     maintenance_schedule = proto.Field(
-        proto.MESSAGE, number=28, message="MaintenanceSchedule",
+        proto.MESSAGE,
+        number=28,
+        message="MaintenanceSchedule",
+    )
+    replica_count = proto.Field(
+        proto.INT32,
+        number=31,
+    )
+    nodes = proto.RepeatedField(
+        proto.MESSAGE,
+        number=32,
+        message="NodeInfo",
+    )
+    read_endpoint = proto.Field(
+        proto.STRING,
+        number=33,
+    )
+    read_endpoint_port = proto.Field(
+        proto.INT32,
+        number=34,
+    )
+    read_replicas_mode = proto.Field(
+        proto.ENUM,
+        number=35,
+        enum=ReadReplicasMode,
     )
-    replica_count = proto.Field(proto.INT32, number=31,)
-    nodes = proto.RepeatedField(proto.MESSAGE, number=32, message="NodeInfo",)
-    read_endpoint = proto.Field(proto.STRING, number=33,)
-    read_endpoint_port = proto.Field(proto.INT32, number=34,)
-    read_replicas_mode = proto.Field(proto.ENUM, number=35, enum=ReadReplicasMode,)
     persistence_config = proto.Field(
-        proto.MESSAGE, number=37, message="PersistenceConfig",
+        proto.MESSAGE,
+        number=37,
+        message="PersistenceConfig",
     )
 
 
@@ -364,13 +462,25 @@ class PersistenceConfig(proto.Message):
         TWELVE_HOURS = 5
         TWENTY_FOUR_HOURS = 6
 
-    persistence_mode = proto.Field(proto.ENUM, number=1, enum=PersistenceMode,)
-    rdb_snapshot_period = proto.Field(proto.ENUM, number=2, enum=SnapshotPeriod,)
+    persistence_mode = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=PersistenceMode,
+    )
+    rdb_snapshot_period = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=SnapshotPeriod,
+    )
     rdb_next_snapshot_time = proto.Field(
-        proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
     )
     rdb_snapshot_start_time = proto.Field(
-        proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -399,10 +509,19 @@ class RescheduleMaintenanceRequest(proto.Message):
         NEXT_AVAILABLE_WINDOW = 2
         SPECIFIC_TIME = 3
 
-    name = proto.Field(proto.STRING, number=1,)
-    reschedule_type = proto.Field(proto.ENUM, number=2, enum=RescheduleType,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    reschedule_type = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=RescheduleType,
+    )
     schedule_time = proto.Field(
-        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -426,11 +545,24 @@ class MaintenancePolicy(proto.Message):
             the maximum number of weekly_window is expected to be one.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    description = proto.Field(proto.STRING, number=3,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=3,
+    )
     weekly_maintenance_window = proto.RepeatedField(
-        proto.MESSAGE, number=4, message="WeeklyMaintenanceWindow",
+        proto.MESSAGE,
+        number=4,
+        message="WeeklyMaintenanceWindow",
     )
 
 
@@ -450,9 +582,21 @@ class WeeklyMaintenanceWindow(proto.Message):
             window. The current window is fixed at 1 hour.
     """
 
-    day = proto.Field(proto.ENUM, number=1, enum=dayofweek_pb2.DayOfWeek,)
-    start_time = proto.Field(proto.MESSAGE, number=2, message=timeofday_pb2.TimeOfDay,)
-    duration = proto.Field(proto.MESSAGE, number=3, message=duration_pb2.Duration,)
+    day = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=dayofweek_pb2.DayOfWeek,
+    )
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timeofday_pb2.TimeOfDay,
+    )
+    duration = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=duration_pb2.Duration,
+    )
 
 
 class MaintenanceSchedule(proto.Message):
@@ -475,11 +619,24 @@ class MaintenanceSchedule(proto.Message):
             beyond, including reschedule.
     """
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    can_reschedule = proto.Field(proto.BOOL, number=3,)
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    can_reschedule = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
     schedule_deadline_time = proto.Field(
-        proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -507,9 +664,18 @@ class ListInstancesRequest(proto.Message):
             request, if any.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListInstancesResponse(proto.Message):
@@ -542,9 +708,19 @@ class ListInstancesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    instances = proto.RepeatedField(proto.MESSAGE, number=1, message="Instance",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
+    instances = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Instance",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetInstanceRequest(proto.Message):
@@ -558,7 +734,10 @@ class GetInstanceRequest(proto.Message):
             where ``location_id`` refers to a GCP region.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GetInstanceAuthStringRequest(proto.Message):
@@ -572,7 +751,10 @@ class GetInstanceAuthStringRequest(proto.Message):
             where ``location_id`` refers to a GCP region.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class InstanceAuthString(proto.Message):
@@ -583,7 +765,10 @@ class InstanceAuthString(proto.Message):
             AUTH string set on the instance.
     """
 
-    auth_string = proto.Field(proto.STRING, number=1,)
+    auth_string = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateInstanceRequest(proto.Message):
@@ -609,9 +794,19 @@ class CreateInstanceRequest(proto.Message):
             Required. A Redis [Instance] resource
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    instance_id = proto.Field(proto.STRING, number=2,)
-    instance = proto.Field(proto.MESSAGE, number=3, message="Instance",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    instance_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    instance = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Instance",
+    )
 
 
 class UpdateInstanceRequest(proto.Message):
@@ -636,9 +831,15 @@ class UpdateInstanceRequest(proto.Message):
     """
 
     update_mask = proto.Field(
-        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=1,
+        message=field_mask_pb2.FieldMask,
+    )
+    instance = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Instance",
     )
-    instance = proto.Field(proto.MESSAGE, number=2, message="Instance",)
 
 
 class UpgradeInstanceRequest(proto.Message):
@@ -655,8 +856,14 @@ class UpgradeInstanceRequest(proto.Message):
             Redis software to upgrade to.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    redis_version = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    redis_version = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class DeleteInstanceRequest(proto.Message):
@@ -670,7 +877,10 @@ class DeleteInstanceRequest(proto.Message):
             where ``location_id`` refers to a GCP region.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GcsSource(proto.Message):
@@ -682,7 +892,10 @@ class GcsSource(proto.Message):
             'gs://my_bucket/my_object').
     """
 
-    uri = proto.Field(proto.STRING, number=1,)
+    uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class InputConfig(proto.Message):
@@ -699,7 +912,10 @@ class InputConfig(proto.Message):
     """
 
     gcs_source = proto.Field(
-        proto.MESSAGE, number=1, oneof="source", message="GcsSource",
+        proto.MESSAGE,
+        number=1,
+        oneof="source",
+        message="GcsSource",
     )
 
 
@@ -716,8 +932,15 @@ class ImportInstanceRequest(proto.Message):
             Required. Specify data to be imported.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    input_config = proto.Field(proto.MESSAGE, number=3, message="InputConfig",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    input_config = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="InputConfig",
+    )
 
 
 class GcsDestination(proto.Message):
@@ -730,7 +953,10 @@ class GcsDestination(proto.Message):
             overwritten.
     """
 
-    uri = proto.Field(proto.STRING, number=1,)
+    uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class OutputConfig(proto.Message):
@@ -747,7 +973,10 @@ class OutputConfig(proto.Message):
     """
 
     gcs_destination = proto.Field(
-        proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
+        proto.MESSAGE,
+        number=1,
+        oneof="destination",
+        message="GcsDestination",
     )
 
 
@@ -764,8 +993,15 @@ class ExportInstanceRequest(proto.Message):
             Required. Specify data to be exported.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    output_config = proto.Field(proto.MESSAGE, number=3, message="OutputConfig",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    output_config = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="OutputConfig",
+    )
 
 
 class FailoverInstanceRequest(proto.Message):
@@ -791,8 +1027,15 @@ class FailoverInstanceRequest(proto.Message):
         LIMITED_DATA_LOSS = 1
         FORCE_DATA_LOSS = 2
 
-    name = proto.Field(proto.STRING, number=1,)
-    data_protection_mode = proto.Field(proto.ENUM, number=2, enum=DataProtectionMode,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    data_protection_mode = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=DataProtectionMode,
+    )
 
 
 class LocationMetadata(proto.Message):
@@ -802,7 +1045,7 @@ class LocationMetadata(proto.Message):
     ``google.cloud.location.Location.metadata`` field.
 
     Attributes:
-        available_zones (Sequence[google.cloud.redis_v1beta1.types.LocationMetadata.AvailableZonesEntry]):
+        available_zones (Mapping[str, google.cloud.redis_v1beta1.types.ZoneMetadata]):
             Output only. The set of available zones in the location. The
             map is keyed by the lowercase ID of each zone, as defined by
             GCE. These keys can be specified in ``location_id`` or
@@ -811,7 +1054,10 @@ class LocationMetadata(proto.Message):
     """
 
     available_zones = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=1, message="ZoneMetadata",
+        proto.STRING,
+        proto.MESSAGE,
+        number=1,
+        message="ZoneMetadata",
     )
 
 
@@ -843,11 +1089,28 @@ class TlsCertificate(proto.Message):
             Sha1 Fingerprint of the certificate.
     """
 
-    serial_number = proto.Field(proto.STRING, number=1,)
-    cert = proto.Field(proto.STRING, number=2,)
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    expire_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    sha1_fingerprint = proto.Field(proto.STRING, number=5,)
+    serial_number = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    cert = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    expire_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    sha1_fingerprint = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
